/**
 *  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import * as lambda from '@aws-cdk/aws-lambda';
import * as cdk from '@aws-cdk/core';
export interface BuildLambdaFunctionProps {
    /**
     * Whether to create a new Lambda function or use an existing Lambda function.
     * If set to false, you must provide a lambda function object as `existingLambdaObj`
     *
     * @default - true
     */
    readonly deployLambda: boolean;
    /**
     * Existing instance of Lambda Function object.
     * If `deploy` is set to false only then this property is required
     *
     * @default - None
     */
    readonly existingLambdaObj?: lambda.Function;
    /**
     * Optional user provided props to override the default props for the Lambda function.
     * If `deploy` is set to true only then this property is required
     *
     * @default - Default props are used
     */
    readonly lambdaFunctionProps?: lambda.FunctionProps;
}
export declare function buildLambdaFunction(scope: cdk.Construct, props: BuildLambdaFunctionProps): lambda.Function;
export declare function deployLambdaFunction(scope: cdk.Construct, lambdaFunctionProps: lambda.FunctionProps, functionId?: string): lambda.Function;
